@@ -3,8 +3,6 @@ use warnings;
 use strict;
 use base qw(App::gh::Command);
 use App::gh::Utils;
-use LWP::Simple qw(get);
-use JSON;
 
 =head1 NAME
 
