@@ -3,8 +3,6 @@ use warnings;
 use strict;
 use base qw(App::gh::Command);
 use App::gh::Utils;
-use LWP::Simple qw(get);
-use JSON;
 
 
 =head1 NAME
@@ -45,7 +43,7 @@ sub options { (
     "ssh" => "protocol_ssh",    # git@github.com:c9s/repo.git
     "http" => "protocol_http",  # http://github.com/c9s/repo.git
     "https" => "protocol_https",         # https://github.com/c9s/repo.git
-    "git|ro"   => "git"         # git://github.com/c9s/repo.git
+    "git|ro"   => "protocol_git"         # git://github.com/c9s/repo.git
 ) }
 
 
@@ -58,7 +56,7 @@ sub run {
         $user = shift;
 
        #copied from Github::Fork::Parent
-       if ($user && $user=~m#^(?:\Qgit://github.com/\E|git\@github\.com:\E|\Qhttp://github.com/\E)([^/]+)/([^/]+)(?:\.git)?$#) {
+       if ($user && $user=~m{^(?:\Qgit://github.com/\E|git\@github\.com:\E|\Qhttp://github.com/\E)([^/]+)/([^/]+)(?:\.git)?$}) {
             ($user,$repo)=($1,$2);
         } elsif( $user && $user =~ /\// ) {
             ($user,$repo) = split /\//,$user;
