@@ -2,9 +2,8 @@ package App::gh::Command::Pull;
 use warnings;
 use strict;
 use base qw(App::gh::Command);
+use App::gh;
 use App::gh::Utils;
-use LWP::Simple qw(get);
-use JSON;
 
 =head1 NAME
 
@@ -61,7 +60,7 @@ sub options { (
         "ssh"      => "protocol_ssh",    # git@github.com:c9s/repo.git
         "http"     => "protocol_http",  # http://github.com/c9s/repo.git
         "https"    => "protocol_https",         # https://github.com/c9s/repo.git
-        "git|ro"   => "git"         # git://github.com/c9s/repo.git
+        "git|ro"   => "protocol_git"         # git://github.com/c9s/repo.git
     ) }
 
 sub run {
